@@ -7,12 +7,12 @@ import random
 from matplotlib import font_manager  # 使用font-manager来管理字体样式，从而解决中文问题
 from matplotlib import pyplot as plt
 
-from quant1x.util import font_simhei
+from quant1x.util import FONT_SimHei
 
 # for font in font_manager.fontManager.ttflist:
 #     print(font.name, '-', font.fname)
 
-my_font = font_manager.FontProperties(fname=font_simhei)  # 使用微软雅黑字体
+my_font = font_manager.FontProperties(fname=FONT_SimHei)  # 使用微软雅黑字体
 
 x = range(0, 120)  # 假设时间轴为10点到12点的每分钟为刻度
 y = [random.randint(20, 35) for i in range(120)]  # 生成120个数值
